@@ -5,7 +5,6 @@ use SG\SgEstateCore\Domain\Model\Badausstattung;
 use SG\SgEstateCore\Domain\Model\Filter;
 use SG\SgEstateCore\Domain\Model\Heizungsart;
 use SG\SgEstateCore\Domain\Model\Immobilie;
-use SG\SgEstateCore\Domain\Model\Kontaktperson;
 use SG\SgEstateCore\Domain\Model\Objektart;
 use SG\SgEstateCore\Domain\Model\Objektarttyp;
 use SG\SgEstateCore\Domain\Model\Ort;
@@ -18,6 +17,7 @@ use SG\SgEstateCore\Domain\Repository\ObjektarttypRepository;
 use SG\SgEstateCore\Domain\Repository\OrtRepository;
 use SG\SgEstateCore\Domain\Repository\RegionRepository;
 use SG\SgEstateCore\Domain\Repository\StadtteilRepository;
+use SG\SgEstateCore\Util\Services;
 use SG\SgEstateCore\Util\SessionHandler;
 use TYPO3\CMS\Core\Cache\CacheManager;
 use TYPO3\CMS\Core\Cache\Frontend\FrontendInterface;
@@ -132,6 +132,18 @@ class BaseController extends ActionController {
         $this->sessionHandler = $sessionHandler;
     }
 
+    /**
+     * @var Services
+     */
+    private $sgEstateCoreServices;
+
+    /**
+     * @param Services $services
+     */
+    public function injectSgEstateCoreServices(Services $services){
+        $this->sgEstateCoreServices = $services;
+    }
+
     /**
      * @var Filter
      */
@@ -296,21 +308,11 @@ class BaseController extends ActionController {
     public function detailAction(){
         $entry = null;
         if ($this->request->hasArgument('realty')){
-            if (isset($this->settings['importids']) && $this->settings['importids'] != ''){
-                $arrayOfImportIds = explode(',', $this->settings['importids']);
-                if (is_array($arrayOfImportIds) && count($arrayOfImportIds) >= 1){}
-                else{
-                    $arrayOfImportIds = [];
-                }
-            }
-            else {
-                $arrayOfImportIds = [];
-            }
-            
-            $cacheIdentifier = 'detail_' . sha1($this->request->getArgument('realty').$this->settings['importids']) . '_L' . $this->getLanguageUid();
+            $cacheIdentifier = 'detail_' . sha1($this->request->getArgument('realty'));
+
             // If $entry is null, it hasn't been cached. Calculate the value and store it in the cache:
             if (($entry = $this->cache->get($cacheIdentifier)) === FALSE) {
-                $realty = $this->immobilieRepository->findOneByUrlIdentifier($this->request->getArgument('realty'), $arrayOfImportIds);
+                $realty = $this->immobilieRepository->findOneByUrlIdentifier($this->request->getArgument('realty'));
                 $this->view->assign('realty', $realty);
 
                 $entry = $this->view->render();
@@ -601,15 +603,7 @@ class BaseController extends ActionController {
         $processedFormValues = array();
         $errors = array();
         foreach ($this->settings['contact']['fields'] as $fieldConfiguration){
-            //if ($fieldConfiguration['required'] == 1 && (!isset($formValues[$fieldConfiguration['name']]) || $formValues[$fieldConfiguration['name']] == '')){
-            if(
-                $fieldConfiguration['required'] == 1
-                && (
-                    !isset($formValues[$fieldConfiguration['name']])
-                    ||
-                    !preg_match("/\\S/", $formValues[$fieldConfiguration['name']])
-                )
-            ) {
+            if ($fieldConfiguration['required'] == 1 && (!isset($formValues[$fieldConfiguration['name']]) || $formValues[$fieldConfiguration['name']] == '')){
                 $errors[$fieldConfiguration['name']][] = 'required';
             }else{
                 $processedFormValues[$fieldConfiguration['name']] = isset($formValues[$fieldConfiguration['name']]) ? $formValues[$fieldConfiguration['name']] : '';
@@ -627,21 +621,16 @@ class BaseController extends ActionController {
         if ($valid){
             // Generate Receivers
             if ($this->settings['contact']['useRealtyContactAsReceiver'] == 1){
-                if( $realty->getKontaktperson() instanceof Kontaktperson ) {
-                    $emailDirekt = $realty->getKontaktperson()->getEmailDirekt();
-                    $emailZentrale = $realty->getKontaktperson()->getEmailZentrale();
-                    $emailSonstige = $realty->getKontaktperson()->getEmailSonstige();
-                    if (GeneralUtility::validEmail($emailDirekt)){
-                        $receivers = array($emailDirekt);
-                    }elseif (GeneralUtility::validEmail($emailZentrale)){
-                        $receivers = array($emailZentrale);
-                    }elseif (GeneralUtility::validEmail($emailSonstige)){
-                        $receivers = array($emailSonstige);
-                    }else{
-                        $receivers = explode(',',$this->settings['contact']['receivers']);
-                    }
-                }
-                else {
+                $emailDirekt = $realty->getKontaktperson()->getEmailDirekt();
+                $emailZentrale = $realty->getKontaktperson()->getEmailZentrale();
+                $emailSonstige = $realty->getKontaktperson()->getEmailSonstige();
+                if (GeneralUtility::validEmail($emailDirekt)){
+                    $receivers = array($emailDirekt);
+                }elseif (GeneralUtility::validEmail($emailZentrale)){
+                    $receivers = array($emailZentrale);
+                }elseif (GeneralUtility::validEmail($emailSonstige)){
+                    $receivers = array($emailSonstige);
+                }else{
                     $receivers = explode(',',$this->settings['contact']['receivers']);
                 }
             }else{
@@ -650,13 +639,18 @@ class BaseController extends ActionController {
 
             if ($this->settings['contact']['addFeedbackAttachment']){
                 $attachmentContent = $this->generateFeedbackAttachment('Email/FeedbackAttachment', array('processedFormValues' => $processedFormValues, 'settings' => $this->settings, 'realty' => $realty), 'xml');
-                $attachment = new \Swift_Attachment($attachmentContent, 'feedback.xml', 'text/xml');
+                $attachment = [
+                    'type' => 'content',
+                    'content' => $attachmentContent,
+                    'filename' => 'feedback.xml'
+                ];
                 $attachments = array($attachment);
             }else{
                 $attachments = array();
             }
 
-            $success = $this->sendTemplateEmail($receivers,array(),$this->settings['contact']['sender'],$this->settings['contact']['subject'],'Email/Contact',array('realty' => $realty, 'formValues' => $processedFormValues, 'settings' => $this->settings),$this->settings['contact']['mailformat'], $attachments);
+
+            $success = $this->sgEstateCoreServices->sendTemplateEmail($receivers,$this->settings['contact']['sender'],$this->settings['contact']['subject'],'SgEstateBaseContact',array(),array('realty' => $realty, 'formValues' => $processedFormValues, 'settings' => $this->settings),$attachments,$this->settings['contact']['mailformat']);
 
             if ($success && intval($this->settings['contact']['redirectPidSuccess'])>0){
                 $uriBuilder = $this->controllerContext->getUriBuilder();
@@ -1065,21 +1059,4 @@ class BaseController extends ActionController {
         $message->send();
         return $message->isSent();
     }
-
-
-    /**
-     * Get the current language
-     */
-    private function getLanguageUid()
-    {
-        $context = GeneralUtility::makeInstance(\TYPO3\CMS\Core\Context\Context::class);
-        $sysLanguageUid = $context->getPropertyFromAspect('language', 'id');
-        if (is_numeric($sysLanguageUid)) {
-            return $sysLanguageUid;
-        } else {
-            return 0;
-        }
-    }
-
-
 }
\ No newline at end of file
