@@ -1,6 +1,6 @@
 <?php
 
-$EM_CONF[$_EXTKEY] = array(
+$EM_CONF['sg_estate_base'] = array(
     'title' => 'sg.estate - Base',
     'description' => 'Base Extension (Search, List, Detail and Contact) for sg_estate',
     'category' => 'plugin',
@@ -10,15 +10,13 @@ $EM_CONF[$_EXTKEY] = array(
     'state' => 'beta',
     'internal' => '',
     'uploadfolder' => '0',
-    'createDirs' => '',
     'clearCacheOnLoad' => 0,
-    'version' => '4.7.8',
+    'version' => '10.0.0',
     'constraints' => array(
         'depends' => array(
-            'typo3' => '9.5.5-9.5.99',
-            'sg_estate_core' => '>=4.8.0',
-            'sg_utilities' => '>=4.1.0',
-            'vhs' => '>=5.1.0'
+            'typo3' => '10.4.4-10.4.99',
+            'sg_estate_core' => '>=10.0.0',
+            'vhs' => '>=6.0.3'
         ),
         'conflicts' => array(
         ),
